﻿package game {
	import flash.display.*;
	import flash.events.*;
	import Collection;
	
	
	public class Player extends MovieClip {
		
		public var standingSpeed:Number;
		public var baseSpeed:Number;
		public var isJumping:Boolean;
		public var isOnGround:Boolean;
		public var isRunning:Boolean = false;
		public var ySpeedOnJump:Number;
		public var obstacles:Collection;
		public var initialJumpSpeed:Number;
		public var acceleration:Number = 1;
		public var vitesseActu:Number = 0;
		public var vies:Number = 2;
		var isPlayingHeadAnimation:Boolean = false;
		var xSpeed:Number;
		var runningPosition:Number = 2;
		var yDecrease:Number;
		var clip:MovieClip;
		
		
		public function Player(standingSpeed:Number = 0, baseSpeed:Number = 0,
							   ySpeedOnJump:Number = 0, yDecrease:Number = 0,
							   initialJumpSpeed:Number = 0) {
			this.standingSpeed = standingSpeed;
			this.baseSpeed = baseSpeed;
			this.ySpeedOnJump = ySpeedOnJump;
			this.yDecrease = yDecrease;
			this.isJumping = true;
			this.isOnGround = false;
			this.initialJumpSpeed = initialJumpSpeed;
			this.xSpeed = 0;
			this.obstacles = new Collection();
		}
		
		public function start():void {
			// clip utilisé pour la course

			this.stand();
			this.playRun();

			this.addEventListener(Event.ENTER_FRAME, movePlayer);
			this.addEventListener(Event.REMOVED_FROM_STAGE, dispose);
		}

		public function moveLeft():void {
			if (vitesseActu > standingSpeed-baseSpeed/2 ){
				vitesseActu -= acceleration;
				
			}
			this.x += vitesseActu;
			
		}
		
		public function moveRight():void {
			if (vitesseActu < baseSpeed){
				vitesseActu += acceleration;
				
			}
			this.x += vitesseActu;
			
		}
		
		public function stand():void {
			if (vitesseActu > standingSpeed + 1){
				vitesseActu -= acceleration*2;
				
			} else if (vitesseActu < standingSpeed - 1){
				vitesseActu += acceleration*2;
			} else {
				vitesseActu = standingSpeed;
			}
			this.x += vitesseActu;
			
			if (!this.isOnGround && !this.isJumping) {
				this.corps.gotoAndStop("stand");
				if (!this.isPlayingHeadAnimation) {
					this.tete.gotoAndStop("stand");
				}
			}
		}
		
		public function jump():void {
			this.isJumping = true;
			this.isOnGround = false;
		}

		function playRun(speed:Number = 2):void {
			switch (speed) {
				case 1:
					this.corps.gotoAndPlay("x-1");
					this.isRunning = true;
					this.runningPosition = 1;
					break;
				case 3:
					this.corps.gotoAndPlay("x2");
					this.isRunning = true;
					this.runningPosition = 3;
					break;
				default:
					this.corps.gotoAndPlay("x1");
					this.isRunning = true;
					this.runningPosition = 2;
			}

			if (!this.isPlayingHeadAnimation) {
				this.tete.gotoAndPlay("run");
			}
		}

		public function escapeCops():void {
			this.vies--;
			this.ySpeedOnJump = 25;
			this.jump();
			this.tete.gotoAndPlay("Siffle");
			this.isPlayingHeadAnimation = true;
		}

		public function playEtonne():void {
			if (!this.isPlayingHeadAnimation) {
				this.tete.gotoAndPlay("Etonne");
				this.isPlayingHeadAnimation = true;
			}
		}

		public function playEssoufle():void {
			if (!this.isPlayingHeadAnimation && Math.random() > .7) {
				this.tete.gotoAndPlay("Essoufle");
				this.isPlayingHeadAnimation = true;
			}
		}

		function movePlayer(event:Event):void {
			var hasHeadCollision = false;
			var hasFeetCollision = false;

			// déplacement en y
			if (this.isJumping) {
				this.corps.gotoAndStop("x1");
				this.y -= this.ySpeedOnJump;
				this.ySpeedOnJump -= this.yDecrease;
				
			}

			// test de collision pour chaque obstacle
			for each (var obstacle:Obstacle in obstacles.itemList) {
				if (this.hitTestObject(obstacle)) {
					// collision

					if (this.x <= obstacle.x || this.x >= obstacle.x + obstacle.width) {
						// collision horizontale		

						if (this.x < obstacle.x) {
							this.x = obstacle.x - this.width/2;			
						} else if (this.x > obstacle.x + obstacle.width) {
							this.x = obstacle.x + obstacle.width + this.width/2;
						}
						
					} else {
						// collision verticale

						if (this.y - this.height <= obstacle.y + obstacle.height
							&& this.y > obstacle.y) {
							// player au dessous de l'obstacle
							this.y = obstacle.y + obstacle.height + 5;
							hasHeadCollision ||= true;
							
						} else if (this.y + this.height >= obstacle.y
								   && this.y < obstacle.y) {
							// player au dessus de l'obstacle
							this.y = obstacle.y - this.height + 15;
							hasFeetCollision ||= true;

							if (obstacle.isGround) {
								this.isOnGround = true;
							} else {
								this.isOnGround = false;
							}
						}
					}
				}
			}

			// "gravité"
			if (!this.isJumping && !hasFeetCollision && !hasHeadCollision) {
				this.isJumping = true;
				this.isOnGround = false;
				this.ySpeedOnJump = 0;
			}
			
			// mise à jour des variables lors d'une collision pendant un saut
			if (this.isJumping) {
				if (hasFeetCollision) {
					this.ySpeedOnJump = this.initialJumpSpeed;
					this.isJumping = false;
					
					// force l'affichage de l'animation
					if (this.isOnGround) {
						// atterissage sur le sol
						if (this.isRunning) {
							switch (runningPosition) {
								case 1:
									this.corps.gotoAndPlay("x-1");
									break;
								case 3:
									this.corps.gotoAndPlay("x2");
									break;
								default:
									this.corps.gotoAndPlay("x1");
							}
							if (!this.isPlayingHeadAnimation) {
								this.tete.gotoAndPlay("run");
							}
						}

					} else {
						// atterissage sur un obstacle
						if (!this.isRunning && (this.runningPosition == 1 || this.runningPosition == 3)) {
							this.corps.gotoAndStop("stand");
							if (!this.isPlayingHeadAnimation) {
								this.tete.gotoAndStop("stand");
							}

						} else {
							if (this.runningPosition == 1) {
								this.corps.gotoAndPlay("x-1");
							} else {
								this.corps.gotoAndPlay("x2");
							}
							this.corps.gotoAndPlay("run");
						}
					}
					
				} else if (hasHeadCollision) {
					this.ySpeedOnJump = 0;
					this.isJumping = true;
				}
			}

			// reset animation visage
			if (this.isPlayingHeadAnimation && 
					(this.tete.currentFrame == 1 || this.tete.currentFrame == 2)) {
				this.isPlayingHeadAnimation = false;
			}
		}
		
		function dispose(event:Event):void {
			this.removeEventListener(Event.ENTER_FRAME, movePlayer);
			this.removeEventListener(Event.REMOVED_FROM_STAGE, dispose);
		}
	}
}
