﻿package game {
	import game.*;
	import flash.display.DisplayObjectContainer;
	import flash.system.System;
	import flash.text.TextField;
	import flash.text.TextFormat;
	import flash.events.*;
	import flash.events.KeyboardEvent;
	import flash.ui.Keyboard;
	import fl.transitions.*;
	import fl.transitions.easing.*;
	import flash.media.SoundMixer;
	
	public class SarkoGame {
		var display:DisplayObjectContainer;
		var scoreText:NiceTextField = null;

		var startScreen:StartScreen = null;
		var selectionScreen:SelectionPerso = null;
		var scrollingRace:ScrollingRace = null;
		var goScreen:GameOverScreen = null;

		var playerSelection:Number = 1;
		
		
		public function SarkoGame(d:DisplayObjectContainer) {
			this.display = d;
			
			this.showStartScreen();
		}
		
		function showStartScreen():void {
			this.startScreen = new StartScreen();
			this.display.addChild(this.startScreen);

			this.display.stage.addEventListener(KeyboardEvent.KEY_DOWN, advanceScreen);
		}
		
		function advanceScreen(event:KeyboardEvent):void {
			this.showSelectionScreen();
		}
		
		function showSelectionScreen():void {
			if (this.startScreen != null) {
				// supprime l'écran précédent
				this.display.stage.removeEventListener(KeyboardEvent.KEY_DOWN, advanceScreen);
				this.display.removeChild(this.startScreen);
				this.startScreen = null;
			}
			
			this.selectionScreen = new SelectionPerso(this.display);
			this.display.addChild(this.selectionScreen);

			this.display.stage.addEventListener(KeyboardEvent.KEY_DOWN, validatePlayer);
		}
		
		function validatePlayer(event:KeyboardEvent):void {
			if (event.keyCode != Keyboard.LEFT && event.keyCode != Keyboard.RIGHT
				&& event.keyCode != Keyboard.UP && event.keyCode != Keyboard.DOWN) {
				this.race();
			}
		}
		
		function race():void {
			if (this.selectionScreen.arabe) {
				this.playerSelection = 1;
			} else if (this.selectionScreen.chinois) {
				 this.playerSelection = 2;
			} else {
				this.playerSelection = 3;
			}
			
			// supprime l'écran précédent
			this.selectionScreen.dispose();
			this.selectionScreen = null;
			this.display.stage.removeEventListener(KeyboardEvent.KEY_DOWN, validatePlayer);
			
						
			// création du score
			this.scoreText = new NiceTextField();
			this.scoreText.x = display.stage.stageWidth - scoreText.width - 10;
			this.scoreText.y = 10;
			this.scoreText.textField.selectable = false;
			this.scoreText.textField.defaultTextFormat = new TextFormat("Playbill", 36, 0xFFFE65,
											false, false, false, null, null, "right");
			this.scoreText.textField.text = "SCORE : 0 m";

			// création de la course
			this.scrollingRace = new ScrollingRace(this.display, playerSelection, this.gameOver, scoreText);			

			this.display.addChild(this.scrollingRace);
			this.display.addChild(this.scoreText);

		}
		
		function gameOver():void {
			var scoreFinal:Number = this.scrollingRace.score;

			// supprime l'écran précédent
			this.scrollingRace.dispose();
			this.scrollingRace = null;
			this.display.removeChild(this.scoreText);

			this.scoreText = new NiceTextField();
			this.scoreText.x = display.stage.stageWidth / 2 - scoreText.width / 2;
			this.scoreText.y = this.display.stage.stageHeight / 2 - scoreText.height / 2;
			this.scoreText.textField.selectable = false;
			this.scoreText.textField.defaultTextFormat = new TextFormat("Playbill", 48, 0xFFFE65,
											false, false, false, null, null, "center");
			this.scoreText.textField.text = "Score final : " + Math.floor(scoreFinal) + " m";

			this.goScreen = new GameOverScreen();
			this.goScreen.flics.sarko.gotoAndStop("caché");
			this.goScreen.x = 0;
			this.goScreen.y = 0;

			switch (this.playerSelection) {
				case 1:
					this.goScreen.blackImmigre.visible = false;
					this.goScreen.chinoisImmigre.visible = false;
					break;
				case 2:
					this.goScreen.blackImmigre.visible = false;
					this.goScreen.arabeImmigre.visible = false;
					break;
				default:
					this.goScreen.arabeImmigre.visible = false;
					this.goScreen.chinoisImmigre.visible = false;
			}

			TransitionManager.start(this.goScreen, {type:Fade, direction:Transition.IN, duration:1, easing:Regular.easeOut});
			this.display.addChild(this.goScreen);
			this.display.addChild(this.scoreText);
		

		}

	}
}
